@@ -3,9 +3,6 @@ from ScraGet.project import get_project
 from ScraGet.studios import get_studio
 from ScraGet.user import get_user, get_user_extra
 from ScraGet.frontpage import get_frontpage
-
-#from ScraGet import frontpage
-
-#import ScraGet
+from ScraGet import ScraGet
 
 print("ScraGet: https://github.com/Quantum-Codes/ScraGet")
\ No newline at end of file
